@@ -14,7 +14,7 @@ async def harvest(
     cancel_timeout: float = _CANCEL_TIMEOUT,
     trustee: Any = None,
     cancel_finish: bool = False,
-):
+) -> None:
     """Run a bunch of awaitables as tasks. Do not return results.
 
     After the harvest returns, all of the awaitables are guaranteed to be done.
@@ -33,7 +33,6 @@ async def harvest(
     consumed before raising `CancelledError`. If `cancel_finish` is True, the
     tasks are not cancelled, but allowed to finish.
     """
-
     tasks = [asyncio.ensure_future(item) for item in aws]
     await harvest_wait(
         tasks,
@@ -53,7 +52,7 @@ async def harvest_results(
     timeout: Optional[float] = None,
     cancel_timeout: float = _CANCEL_TIMEOUT,
     trustee: Any = None,
-):
+) -> tuple[bool, list[Any]]:
     """Run a bunch of awaitables as tasks and return (cancelled, results).
 
     ```
@@ -75,7 +74,6 @@ async def harvest_results(
     If `harvest_results` is cancelled itself, all awaitables are cancelled and
     `cancelled` is returned as True.
     """
-
     tasks = [asyncio.ensure_future(item) for item in aws]
     cancelled = False
     try:
@@ -97,7 +95,7 @@ async def harvest_wait(
     cancel_timeout: float = _CANCEL_TIMEOUT,
     cancel_finish: bool = False,
     trustee: Any = None,
-):
+) -> None:
     """Wait for tasks to finish or raise an exception.
 
     After the harvest returns, all of the tasks are guaranteed to be done.
@@ -113,12 +111,13 @@ async def harvest_wait(
     consumed before raising `CancelledError`. If `cancel_finish` is True,
     the tasks are not cancelled, but allowed to finish.
     """
-
     try:
         # Wait for all tasks to complete, the first one to raise an
         # exception, or a timeout.
         done, pending = await asyncio.wait(
-            tasks, timeout=timeout, return_when=asyncio.FIRST_EXCEPTION
+            tasks,
+            timeout=timeout,
+            return_when=asyncio.FIRST_EXCEPTION,
         )
 
         # Determine whether asyncio.wait timed out.
@@ -134,7 +133,7 @@ async def harvest_wait(
     except (asyncio.CancelledError, GeneratorExit) as ex:
         # Cancel all tasks and wait for them to finish.
         if LOG_DETAIL:
-            LOGGER.info(
+            LOGGER.debug(
                 "harvest_wait cancelled trustee=%r cancel_finish=%r ex=%r",
                 trustee,
                 cancel_finish,
@@ -151,7 +150,7 @@ async def harvest_wait(
 
     if time_expired:
         if LOG_DETAIL:
-            LOGGER.info("harvest_wait timed out trustee=%r", trustee)
+            LOGGER.debug("harvest_wait timed out trustee=%r", trustee)
         _consume_exceptions(tasks)
         raise asyncio.TimeoutError()
 
@@ -183,7 +182,6 @@ async def _cancel_waiter(
     timeout: float,
 ):
     "Handle case where _cancel_wait is cancelled itself."
-
     _, pending = await asyncio.wait(
         tasks,
         timeout=timeout,
