@@ -6,10 +6,12 @@ import contextvars
 import errno
 import os
 import struct
+import warnings
 from dataclasses import dataclass
 from typing import Any, Callable, NamedTuple, Optional, Union
 
 # The following modules are not supported on Windows.
+# pyright: reportPossiblyUnboundVariable=false
 try:
     import fcntl
     import pty
@@ -262,7 +264,9 @@ _IGNORE_CHILD_PROCESS = contextvars.ContextVar("ignore_child_process", default=F
 
 def _patch_child_watcher():
     "Patch the current child watcher for `add_child_handler`."
-    watcher = asyncio.get_child_watcher()
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore", DeprecationWarning)
+        watcher = asyncio.get_child_watcher()  # pyright: ignore[reportDeprecated]
 
     # Check flag to see if patch already exists.
     if hasattr(watcher, "_shellous_patched"):
